@@ -31,6 +31,7 @@ __all__ = (
     "MemberPermissionsType",
     "PermissionsType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -341,3 +342,4 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["describe_environment_memberships", "list_environments"]
